@@ -18,7 +18,7 @@ parsnip::multi_predict
 
 utils::globalVariables(
   c(
-    ".pred_1", ".pred_2", ".pred_class", ".rows", "object", "new_data", "name",
+    ".pred_1", ".pred_2", ".pred_class", ".row_number", "object", "new_data", "name",
     ".pred", "(Intercept)", "committee", "rule", "trials"
   )
 )
