@@ -419,6 +419,13 @@ multi_predict._cubist <-
     } else {
       n <- length(neighbors)
     }
+
+    new_data <- parsnip::prepare_data(object, new_data)
+    # preprocess data
+    if (!is.null(object$spec$method$pred$numeric$pre)) {
+      new_data <- object$spec$method$pred$numeric$pre(new_data, object)
+    }
+
     res <- cubist_pred(object, new_data, neighbors = neighbors, ...)
     if (n > 1) {
       res$.row_number <- rep(1:nrow(new_data), n)
